## R1704 (redefined-argument-from-local)

### :x: Problematic code:

```python
def main(host_id="test"):
    for host_id, host in [[1, 2]]:
        print(host_id, host)
```

### :heavy_check_mark: Correct code:

```python
def main(host_id="test"):
    for h_id, host in [[1, 2]]:
        print(host_id, h_id, host)
```

### Rationale:

Used when a local name is redefining an argument, which might suggest a
potential error. This is taken in account only for a handful of name binding
operations, such as for iteration, with statement assignment and exception
handler assignment.

### Related resources:

- [Issue Tracker](https://github.com/PyCQA/pylint/issues?q=is%3Aissue+%22redefined-argument-from-local%22+OR+%22R1704%22)
